@@ -55,7 +55,7 @@ class ParquetReader:
 
         self.headers = df
 
-    def __call__(self, batch_size, start=0, end=None, max_piece_size=None, parallel_pieces=10):
+    def __call__(self, batch_size, start=0, end=None, max_piece_size=None, parallel_pieces=10, show_progress=True):
         if end is None:
             end = self.headers["count"].sum()
 
@@ -66,11 +66,12 @@ class ParquetReader:
 
         parallel_pieces = 10
         if max_piece_size is None:
-            max_piece_size = max(batch_size // parallel_pieces, 1)
+            max_piece_size = max(int(50 * 10 ** 6 / (self.byte_per_item)), 1)
 
         pieces = build_pieces(
             headers=self.headers, batch_size=batch_size, start=start, end=end, max_piece_size=max_piece_size
         )
+        batch_count = pieces["batch_id"].max() + 1
 
         cols = [
             "filename",
@@ -114,6 +115,9 @@ class ParquetReader:
         batch = None
         batch_meta = None
         batch_offset = 0
+
+        if show_progress:
+            pbar = tqdm(total=batch_count)
         with ThreadPool(parallel_pieces) as p:
             for data, meta, piece in p.imap(read_piece, piece_generator(pieces)):
                 if batch is None:
@@ -137,4 +141,9 @@ class ParquetReader:
                     if self.metadata_column_names is not None:
                         batch_meta = None
                     batch_offset = 0
+                    if show_progress:
+                        pbar.update(1)
                 semaphore.release()
+
+        if show_progress:
+            pbar.close()
